---
title: Introduction
---

The Judgment platform is a tool for viewing and analyzing evaluations in **development and production**. 

Login [here](https://app.judgmentlabs.ai/) to start using the platform.

TODO add screenshot of platform


